function ESS_contour_plot
    clf
    
    % set beta and gamma values for the contour plot
    
    beta_range=[1:0.05:3];
    gamma_range=[0.15:0.025:1];
    
    % set up grid of values
    [GAMMA,BETA]=meshgrid(gamma_range,beta_range);
    
    % calculate ESS for each point on grid
    for i=1:numel(beta_range)
        for j=1:numel(gamma_range)
            ESS(i,j)=error_sum_of_squares([BETA(i,j),GAMMA(i,j)]);
        end
    end
    
    % do contour plot, with gamma on horizontal, beta on vertical
    
    figure(1)
    contour(GAMMA,BETA,ESS,20)
    
    % do surface plot
    figure(2)
    mesh(GAMMA,BETA,ESS)
    
end


function ESS=error_sum_of_squares(input_pars)

    beta=input_pars(1);
    gamma=input_pars(2);
    N=763;
    
    pars=[beta,gamma,N];
    
    tspan=[0:13];	  % 14 days of data, including initial value
    y0=[760;3];       % take initial conditions to be S(0)=760, I(0)=3 
    
    y=lsode(@(x, t) sir_rhs(t,x,pars),y0,tspan);

    ESS=0;
    data=[3;6;25;73;222;294;258;237;191;125;69;27;11;4];
    % initial value plus 13 more values
    
    diff=data-y(:,2);  % calculate differences between data and predictions

    ESS=sum(diff.^2);  % square entries of diff and then sum
    % note: there are 14 terms in this sum, but one (the first) is zero
end

function f = sir_rhs(t,y,pars)
    f=zeros(2,1);
    f(1)=-pars(1)*y(1)*y(2)/pars(3);
    f(2)=pars(1)*y(1)*y(2)/pars(3)-pars(2)*y(2);
end
