function sir_parameter_uncertainties
    clf               % clear any previous figures

    % use best fitting parameter values 
    beta=1.69268;
    gamma=0.44847;
    
    % use error sum of squares calculated in fitting routine
    ess=4251.2;
    
    pars=[beta,gamma,763];

    tspan=[0:13];		 % simulate for 13 days
    y0=[760;3;0;0;0;0];       % three initial infectives
                              % four sensitivities are initially zero
                              
% recall : component 1 is S, component 2 is I
% component 3 is dS/dbeta, component 4 is dS/dgamma
% component 5 is dI/dbeta, component 6 is dI/dgamma
	
  y=lsode(@(x, t) sir_sens_rhs(t,x,pars),y0,tspan); 
  
% y(:,5) is the vector of dI/dbeta values
% y(:,6) is the vector of dI/dgamma values

% NOTE: we don't want the first entries of these, because they correspond
% to the initial condition, which we assumed was exact
% (14 points in vectors, but treat only 13 of them as data points)

% form chi matrix.  The "2:14" pulls out the 13 required values, dropping
% the first entry
    chi=zeros(13,2);
    chi(:,1)=y(2:14,5);
    chi(:,2)=y(2:14,6);
    
    Sigma=(ess/(13-2))*inv(transpose(chi)*chi)

    SE_beta=sqrt(Sigma(1,1))
    CV_beta=SE_beta/beta
    
    SE_gamma=sqrt(Sigma(2,2))
    CV_gamma=SE_gamma/gamma
    
    rho=Sigma(1,2)/(SE_beta*SE_gamma)
    
end

function f = sir_sens_rhs(t,y,pars)
    f=zeros(6,1);
    
    beta=pars(1);
    gamma=pars(2);
    N=pars(3);
    S=y(1);
    I=y(2);
    
    f(1)=-beta*S*I/N;
    f(2)=beta*S*I/N-gamma*I;
    
    f(3)=-(beta*I/N)*y(3)-(beta*S/N)*y(5)-S*I/N;
    f(4)=-(beta*I/N)*y(4)-(beta*S/N)*y(6);
    
    f(5)=(beta*I/N)*y(3)+(beta*S/N-gamma)*y(5)+S*I/N;
    f(6)=(beta*I/N)*y(4)+(beta*S/N-gamma)*y(6)-I;
    
end
