function sir_simulation
  
    beta=1.0;
    gamma=1.0/5.0;    % five day infectious period	
    N=1000.0;
    pars=[beta,gamma,N];
    
    tspan=[0:0.1:50];     % simulate for 50 days
    y0=[999;1];       % one initial infective
    
    y=lsode(@(x, t) sir_rhs(t,x,pars),y0,tspan);

% notice : function that lsode uses to evaluate derivatives (i.e. RHS of our
% ODE) has x as first argument, t as second (opposite order to that used by
% ode45), and also doesn't let us pass parameters directly, so we have to use
% this @(x,t) sir_rhs(t,x,pars) construct    
% Finally, y0 and tspan are 2nd and 3rd arguments of lsode (c.f. 3rd and 2nd
% for ode45 )
    
    plot(tspan,y(:,2));   % plot prevalence of infection (i.e. I(t)) over time

    hold on
    plot(tspan,y(:,1),'--');   % add susceptibles vs time to the plot
                           % as a dashed line
    hold off
    
end

function f = sir_rhs(t,y,pars)
 
   f=zeros(2,1);
   f(1)=-pars(1)*y(1)*y(2)/pars(3);
   f(2)=pars(1)*y(1)*y(2)/pars(3)-pars(2)*y(2);
end
